==> 0.0.2.tar.gz: lib/nan_map_page.dart <==
import 'package:flutter/material.dart';
import 'package:nan_map/nan_map_widget.dart';

const VIEW_TYPE = 'com.amap.flutter.map';
class NanMapPage extends StatefulWidget{

  final String locationImg;
  final double width;
  final double height;
  final double radius;
  final String path;
  final double locaTop;
  final double locaBottom;
  final double locaLeft;
  final double locaRight;
  final Function finishFun;
  final bool isHiddenCoverage;//是否显示图层,默认隐藏
  final Function returnResult;
  NanMapPage({
    Key key,
    this.locationImg = "location",
    this.width = 50,
    this.height = 50,
    this.radius = 25,
    this.path = "img",
    this.locaTop = 80,
    this.locaBottom,
    this.locaLeft,
    this.locaRight=10,
    this.finishFun,
    this.isHiddenCoverage = true,
    this.returnResult
  }):super(key: key);

  @override
  _NanMapPageState createState() => _NanMapPageState();


}
class _NanMapPageState extends State<NanMapPage>{
  NanMapController controller = NanMapController();
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();

  }


  @override
  Widget build(BuildContext context) {

    return Scaffold(
      appBar: AppBar(
        title: Text("地图选择"),
        actions: <Widget>[
          builderItem(title: '确定',onTap: () {
            
          },),
        ],
      ),
      // body: NanMapWidget(isHiddenCoverage: widget.isHiddenCoverage,locaLeft: widget.locaLeft,locaRight: widget.locaRight,locaTop: widget.locaTop,
      //       locaBottom: widget.locaBottom,locationImg:widget.locationImg,returnResult: widget.returnResult,controller: controller,)

      body: Stack(
        children: [
          NanMapWidget(returnResult: widget.returnResult,controller: controller,apiKey: "高德开放平台申请的ApiKey",),
          Positioned(
            right: widget.locaRight,
            top: 80.0+60,
            child: coverageWidget(img: widget.locationImg,onTap: (){
              controller.currentPosition();
            })
          ),

          Positioned(
            top: widget.locaTop,
            right: widget.locaRight,
            left: widget.locaLeft,
            bottom: widget.locaBottom,
            child: Offstage(
              offstage: widget.isHiddenCoverage,
              child: coverageWidget(img: "coverage_nor",onTap: (){
                showCoverage(context,selectResult: (index){
                  controller.setMapType(mapType: index);
                });
              }),
            )
          ),
          
        ],
      )

    );
  }

  Builder builderItem({String imgName='fenlei',String title='问题上报',double right=10,GestureTapCallback onTap}){
    return new Builder(
      builder: (context){
        return InkWell(
          child: Container(
            margin: EdgeInsets.only(right: right),
            alignment: Alignment.center,
            child: Text(title),
          ),
          onTap: onTap,
        ); 
      },
    );
  }

  Widget coverageWidget({String img="location",GestureTapCallback onTap}){
    return InkWell(
      child: Container(
        width: widget.width,
        height: widget.height,
        padding: EdgeInsets.all(10),
        // margin: EdgeInsets.only(left: widget.left,right: widget.left),
        decoration: BoxDecoration(
          // gradient: LinearGradient(
          //   colors: [Color.fromRGBO(0,227,174, 1),Colous.Color149144]
          // ),
          boxShadow: [
            // BoxShadow(color: Color(0x99FFFF00), offset: Offset(3.0, 3.0), blurRadius: 10.0, spreadRadius: 2.0), 
            BoxShadow(color: Color.fromRGBO(255, 255, 255, 1), offset: Offset(0.5, 0.5)), 
            BoxShadow(color: Color.fromRGBO(	105,105,105, 1))
          ],
          color: Colors.white,
          borderRadius: BorderRadius.all(Radius.circular(widget.radius))
        ),
        
        child: loadAssetImage(img,width: 30,height: 30,path: widget.path,onTap: onTap,)
      
      ),
      onTap: (){
        
      },
    );
  }

  Widget loadAssetImage(String name,{String path="img",double width,double height,BoxFit fit,String format:'png',GestureTapCallback onTap}){
    return InkWell(
      child: Image.asset(
        getImagePath(name,format: format,path: path),
        height: height,
        width: width,
        fit: fit,
      ),
      onTap: onTap,
    );
  }

  String getImagePath(String name,{String path="img",String format:'png'}){
    return '$path/$name.$format';
  }

  void showCoverage(BuildContext context,{List choiceList,Function selectResult}){//相机与相册
    List coverageList = ["标准地图","卫星地图","夜景模式地图","导航模式地图"];
    showModalBottomSheet(context: context, builder: (BuildContext context){
      return SizedBox(
        // height: 200,
        child: ListView.builder(itemCount: coverageList.length,itemBuilder: (context, index){
          String map = coverageList[index];
          return ListTile(
            title: new Text(map),
            onTap: (){
              Navigator.of(context).pop();
              selectResult(index+1);
            },
          );
        }),
      );
    });
  }

}

==> 0.0.3.tar.gz: lib/nan_map_page.dart <==
import 'package:flutter/material.dart';
import 'package:nan_map/nan_map_widget.dart';

const VIEW_TYPE = 'com.amap.flutter.map';
class NanMapPage extends StatefulWidget{

  final String locationImg;
  final double width;
  final double height;
  final double radius;
  final String path;
  final double locaTop;
  final double locaBottom;
  final double locaLeft;
  final double locaRight;
  final Function finishFun;
  final bool isHiddenCoverage;//是否显示图层,默认隐藏
  final Function returnResult;
  final String apiKey;
  NanMapPage({
    Key key,
    this.locationImg = "location",
    this.width = 50,
    this.height = 50,
    this.radius = 25,
    this.path = "img",
    this.locaTop = 80,
    this.locaBottom,
    this.locaLeft,
    this.locaRight=10,
    this.finishFun,
    this.isHiddenCoverage = true,
    this.returnResult,
    this.apiKey
  }):super(key: key);

  @override
  _NanMapPageState createState() => _NanMapPageState();


}
class _NanMapPageState extends State<NanMapPage>{
  NanMapController controller = NanMapController();
  Map messageData={};
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();

  }


  @override
  Widget build(BuildContext context) {

    return Scaffold(
      appBar: AppBar(
        title: Text("地图选择"),
        actions: <Widget>[
          builderItem(title: '确定',onTap: () {
            if (widget.finishFun != null) {
              widget.finishFun(messageData);
              Navigator.pop(context);
            }
          },),
        ],
      ),
      // body: NanMapWidget(isHiddenCoverage: widget.isHiddenCoverage,locaLeft: widget.locaLeft,locaRight: widget.locaRight,locaTop: widget.locaTop,
      //       locaBottom: widget.locaBottom,locationImg:widget.locationImg,returnResult: widget.returnResult,controller: controller,)

      body: Stack(
        children: [
          NanMapWidget(returnResult: (message){
            messageData = message;
          },controller: controller,apiKey: "${widget.apiKey}",),
          Positioned(
            right: widget.locaRight,
            top: 80.0+60,
            child: coverageWidget(img: widget.locationImg,onTap: (){
              controller.currentPosition();
            })
          ),

          Positioned(
            top: widget.locaTop,
            right: widget.locaRight,
            left: widget.locaLeft,
            bottom: widget.locaBottom,
            child: Offstage(
              offstage: widget.isHiddenCoverage,
              child: coverageWidget(img: "coverage_nor",onTap: (){
                showCoverage(context,selectResult: (index){
                  controller.setMapType(mapType: index);
                });
              }),
            )
          ),
          
        ],
      )

    );
  }

  Builder builderItem({String imgName='fenlei',String title='问题上报',double right=10,GestureTapCallback onTap}){
    return new Builder(
      builder: (context){
        return InkWell(
          child: Container(
            margin: EdgeInsets.only(right: right),
            alignment: Alignment.center,
            child: Text(title),
          ),
          onTap: onTap,
        ); 
      },
    );
  }

  Widget coverageWidget({String img="location",GestureTapCallback onTap}){
    return InkWell(
      child: Container(
        width: widget.width,
        height: widget.height,
        padding: EdgeInsets.all(10),
        // margin: EdgeInsets.only(left: widget.left,right: widget.left),
        decoration: BoxDecoration(
          // gradient: LinearGradient(
          //   colors: [Color.fromRGBO(0,227,174, 1),Colous.Color149144]
          // ),
          boxShadow: [
            // BoxShadow(color: Color(0x99FFFF00), offset: Offset(3.0, 3.0), blurRadius: 10.0, spreadRadius: 2.0), 
            BoxShadow(color: Color.fromRGBO(255, 255, 255, 1), offset: Offset(0.5, 0.5)), 
            BoxShadow(color: Color.fromRGBO(	105,105,105, 1))
          ],
          color: Colors.white,
          borderRadius: BorderRadius.all(Radius.circular(widget.radius))
        ),
        
        child: loadAssetImage(img,width: 30,height: 30,path: widget.path,onTap: onTap,)
      
      ),
      onTap: (){
        
      },
    );
  }

  Widget loadAssetImage(String name,{String path="img",double width,double height,BoxFit fit,String format:'png',GestureTapCallback onTap}){
    return InkWell(
      child: Image.asset(
        getImagePath(name,format: format,path: path),
        height: height,
        width: width,
        fit: fit,
      ),
      onTap: onTap,
    );
  }

  String getImagePath(String name,{String path="img",String format:'png'}){
    return '$path/$name.$format';
  }

  void showCoverage(BuildContext context,{List choiceList,Function selectResult}){//相机与相册
    List coverageList = ["标准地图","卫星地图","夜景模式地图","导航模式地图"];
    showModalBottomSheet(context: context, builder: (BuildContext context){
      return SizedBox(
        // height: 200,
        child: ListView.builder(itemCount: coverageList.length,itemBuilder: (context, index){
          String map = coverageList[index];
          return ListTile(
            title: new Text(map),
            onTap: (){
              Navigator.of(context).pop();
              selectResult(index+1);
            },
          );
        }),
      );
    });
  }

}
